@@ -1,7 +1,7 @@
 package Setup::File::TextFragment;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -193,7 +193,7 @@ Setup::File::TextFragment - Insert/delete text fragment in a file (with undo sup
 
 =head1 VERSION
 
-This document describes version 0.04 of Setup::File::TextFragment (from Perl distribution Setup-File-TextFragment), released on 2015-08-18.
+This document describes version 0.05 of Setup::File::TextFragment (from Perl distribution Setup-File-TextFragment), released on 2015-09-04.
 
 =head1 SEE ALSO
 
@@ -206,9 +206,8 @@ L<Setup>
 
 =head2 setup_text_fragment(%args) -> [status, msg, result, meta]
 
-{en_US Insert/delete text fragment in a file (with undo support)}.
+Insert/delete text fragment in a file (with undo support).
 
-{en_US 
 On do, will insert fragment to file (or delete, if C<should_exist> is set to
 false). On undo, will restore old file.
 
@@ -222,7 +221,6 @@ false).
 Fixable state: file exists, fragment doesn't exist or payload is not the same
 (if C<should_exist> is true) or fragment still exists (if C<should_exist> is
 false).
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -233,43 +231,43 @@ Arguments ('*' denotes required arguments):
 
 =item * B<attrs> => I<hash>
 
-{en_US Fragment attributes (only for inserting new fragment), passed to Text::Fragment}.
+Fragment attributes (only for inserting new fragment), passed to Text::Fragment.
 
 =item * B<comment_style> => I<bool>
 
-{en_US Will be passed to Text::Fragment}.
+Will be passed to Text::Fragment.
 
 =item * B<good_pattern> => I<str>
 
-{en_US Will be passed to Text::Fragment}.
+Will be passed to Text::Fragment.
 
 =item * B<id>* => I<str>
 
-{en_US Fragment ID}.
+Fragment ID.
 
 =item * B<label> => I<str>
 
-{en_US Will be passed to Text::Fragment}.
+Will be passed to Text::Fragment.
 
 =item * B<path>* => I<str>
 
-{en_US Path to file}.
+Path to file.
 
 =item * B<payload>* => I<str>
 
-{en_US Fragment content}.
+Fragment content.
 
 =item * B<replace_pattern> => I<str>
 
-{en_US Will be passed to Text::Fragment}.
+Will be passed to Text::Fragment.
 
 =item * B<should_exist> => I<bool> (default: 1)
 
-{en_US Whether fragment should exist}.
+Whether fragment should exist.
 
 =item * B<top_style> => I<bool>
 
-{en_US Will be passed to Text::Fragment}.
+Will be passed to Text::Fragment.
 
 =back
 
